Module go

Module go 

Structs

FuncDef
Function definition
GoCache
Cache for parsed Go packages. Stdlib packages use a global cache; project-specific packages are per-instance.
GoPackage
Extracted information from a Go package
Param
Function parameter
Project
Resolver
Resolver for import paths
SourceLocation
Source location in a Go file
TypeDef
Type definition

Enums

ImportKind
The kind of import and where to find its source

Functions

parse_go_type
Parse a Go type string into a Soppo Type.