Structs
- FuncDef
- Function definition
- GoCache
- Cache for parsed Go packages. Stdlib packages use a global cache; project-specific packages are per-instance.
- GoPackage
- Extracted information from a Go package
- Param
- Function parameter
- Project
- Resolver
- Resolver for import paths
- Source
Location - Source location in a Go file
- TypeDef
- Type definition
Enums
- Import
Kind - The kind of import and where to find its source
Functions
- parse_
go_ type - Parse a Go type string into a Soppo Type.